"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.deactivate = exports.activate = void 0;
const vscode_1 = require("vscode");
const ts_1 = require("./parsers/ts");
const utils_1 = require("./utils");
const EXTENSION_NAME = 'js-move-around';
var MoveCommand;
(function (MoveCommand) {
    MoveCommand["backward"] = "move-backward";
    MoveCommand["forward"] = "move-forward";
})(MoveCommand || (MoveCommand = {}));
var SwapCommand;
(function (SwapCommand) {
    SwapCommand["select"] = "select-for-swap";
    SwapCommand["swap"] = "swap";
})(SwapCommand || (SwapCommand = {}));
const activate = (ctx) => {
    [MoveCommand.backward, MoveCommand.forward].forEach((commandName) => {
        ctx.subscriptions.push(vscode_1.commands.registerCommand(`${EXTENSION_NAME}.${commandName}`, async () => {
            const editor = vscode_1.window.activeTextEditor;
            if (!editor)
                return;
            try {
                const config = vscode_1.workspace.getConfiguration(EXTENSION_NAME);
                const scopeRange = await ts_1.parser.getScopeRange(editor, {
                    getConfig: (name) => config.get(name),
                });
                if (!scopeRange)
                    return;
                const { index, tokens } = scopeRange;
                const token1 = tokens[index];
                const token2 = commandName === MoveCommand.backward
                    ? tokens[index - 1]
                    : tokens[index + 1];
                if (token1 && token2) {
                    await (0, utils_1.swap)(editor, [token1, token2]);
                }
            }
            catch (e) {
                vscode_1.window.showErrorMessage(e.message);
            }
        }));
    });
    const selectSwapCommand = `${EXTENSION_NAME}.${SwapCommand.select}`;
    ctx.subscriptions.push(vscode_1.commands.registerCommand(selectSwapCommand, async () => {
        const editor = vscode_1.window.activeTextEditor;
        if (!editor) {
            return;
        }
        await ctx.workspaceState.update(selectSwapCommand, editor.selection);
        await vscode_1.commands.executeCommand('setContext', selectSwapCommand, true);
    }));
    ctx.subscriptions.push(vscode_1.commands.registerCommand(`${EXTENSION_NAME}.${SwapCommand.swap}`, async () => {
        const editor = vscode_1.window.activeTextEditor;
        if (!editor) {
            return;
        }
        const selection = ctx.workspaceState.get(selectSwapCommand);
        if (selection) {
            await (0, utils_1.swap)(editor, [selection, editor.selection]);
        }
        await vscode_1.commands.executeCommand('setContext', selectSwapCommand, false);
    }));
};
exports.activate = activate;
const deactivate = () => { };
exports.deactivate = deactivate;
//# sourceMappingURL=extension.js.map