"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getNodeRange = void 0;
const typescript_1 = require("typescript");
const getDefaultRange = ({ node, sourceFile, }) => {
    const rangeNode = (0, typescript_1.isTemplateLiteralTypeSpan)(node)
        ? node.type
        : (0, typescript_1.isTemplateSpan)(node)
            ? node.expression
            : node;
    return {
        end: rangeNode.getEnd(),
        start: rangeNode.getStart(sourceFile),
    };
};
const getJsxTextRange = ({ node, sourceFile, }) => {
    if (!(0, typescript_1.isJsxText)(node))
        return undefined;
    const start = node.getStart(sourceFile);
    return {
        end: start + node.text.trim().length,
        start,
    };
};
const getTypeElementRange = ({ node, parent, sourceFile, }) => {
    if (!typescript_1.isTypeElement)
        return undefined;
    if (!(0, typescript_1.isInterfaceDeclaration)(parent) && !(0, typescript_1.isTypeLiteralNode)(parent))
        return undefined;
    const text = node.getText(sourceFile);
    const start = node.getStart(sourceFile);
    return {
        end: start + text.length - (/[,;]$/.test(text) ? 1 : 0),
        start,
    };
};
const getNodeRange = (args) => getJsxTextRange(args) || getTypeElementRange(args) || getDefaultRange(args);
exports.getNodeRange = getNodeRange;
//# sourceMappingURL=getNodeRange.js.map