"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getSelectionScope = void 0;
const typescript_1 = require("typescript");
const types_1 = require("../../types");
const utils_1 = require("../../utils");
const nodeContainsRange = ({ end: nodeEnd, pos: nodeStart }, { end: rangeEnd, start: rangeStart }) => nodeStart <= rangeStart && nodeEnd >= rangeEnd;
const filterOutWhiteSpacesJsxTexts = (parent, children) => (0, typescript_1.isJsxElement)(parent) || (0, typescript_1.isJsxFragment)(parent)
    ? parent.children.filter(child => !(0, typescript_1.isJsxText)(child) || !child.containsOnlyTriviaWhiteSpaces)
    : children;
const getOptionalScope = (parent, child, { getConfig }) => {
    let children;
    if (!children &&
        getConfig(types_1.ConfigName.enableBinaryExpression) &&
        (0, typescript_1.isBinaryExpression)(parent)) {
        children = [parent.left, parent.right];
    }
    if (!children &&
        getConfig(types_1.ConfigName.enableConditionalExpression) &&
        (0, typescript_1.isConditionalExpression)(parent)) {
        children = [parent.whenTrue, parent.whenFalse];
    }
    if (!children &&
        getConfig(types_1.ConfigName.enableConditionalType) &&
        (0, typescript_1.isConditionalTypeNode)(parent)) {
        children = [parent.trueType, parent.falseType];
    }
    if (!children &&
        getConfig(types_1.ConfigName.enableIfStatement) &&
        (0, typescript_1.isIfStatement)(parent) &&
        parent.elseStatement) {
        children = [parent.thenStatement, parent.elseStatement];
    }
    const index = children?.indexOf(child);
    if (children && typeof index === 'number' && index > -1) {
        return {
            child,
            children,
            index,
            parent,
        };
    }
    return undefined;
};
const walk = (node, range, context, target) => (0, typescript_1.forEachChild)(node, childNode => {
    if (!nodeContainsRange(childNode, range))
        return undefined;
    const parent = target.targetNode;
    target.targetNode = childNode;
    const scope = getOptionalScope(parent, childNode, context);
    if (scope)
        target.scope = scope;
    const grandChild = walk(childNode, range, context, target);
    return grandChild ?? childNode;
}, childNodes => {
    if (!nodeContainsRange(childNodes, range))
        return undefined;
    const parent = target.targetNode;
    const children = filterOutWhiteSpacesJsxTexts(parent, childNodes);
    for (let index = 0; index < children.length; ++index) {
        const child = children[index];
        if (!nodeContainsRange(child, range))
            continue;
        if (!context.getConfig(types_1.ConfigName.enablePropagation) ||
            children.length > 1)
            target.scope = { index, children, child, parent };
        target.targetNode = child;
        return walk(child, range, context, target) || child;
    }
    return undefined;
});
const getSelectionScope = (sourceFile, editor, context) => {
    const target = {
        targetNode: sourceFile,
    };
    walk(sourceFile, (0, utils_1.getSelectionOffsetRange)(editor), context, target);
    return target;
};
exports.getSelectionScope = getSelectionScope;
//# sourceMappingURL=getSelectionScope.js.map